prai :pray:
===========
Raiblocks Python RPC client

Some notes
----------

This is work in progress, so expect some rough edges and stay tuned for updates :see_no_evil:

Roadmap
-------

- Finish basic API
- Add some higher-level features, for example a simple e-commerce payment API
- Add more validation and tests (ughhh)
- Make package, submit to pypi :tada:


